==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_results/mp0012_001/MP0012_GetWorkRequest_001_Result.java <==

package net.datastream.schemas.mp_results.mp0012_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0012_001}ResultData"/>
 *       &lt;/sequence>
 *       &lt;attribute name="jtauth_can_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0012_GetWorkRequest_001_Result")
public class MP0012_GetWorkRequest_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected ResultData resultData;
    @XmlAttribute(name = "jtauth_can_update")
    protected String jtauth_Can_Update;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link ResultData }
     *     
     */
    public ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link ResultData }
     *     
     */
    public void setResultData(ResultData value) {
        this.resultData = value;
    }

    /**
     * Obtient la valeur de la propriété jtauth_Can_Update.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJtauth_Can_Update() {
        if (jtauth_Can_Update == null) {
            return "true";
        } else {
            return jtauth_Can_Update;
        }
    }

    /**
     * Définit la valeur de la propriété jtauth_Can_Update.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJtauth_Can_Update(String value) {
        this.jtauth_Can_Update = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_results/mp0012_001/MP0012_GetWorkRequest_001_Result.java <==

package net.datastream.schemas.mp_results.mp0012_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0012_001}ResultData"/>
 *       &lt;/sequence>
 *       &lt;attribute name="jtauth_can_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0012_GetWorkRequest_001_Result")
public class MP0012_GetWorkRequest_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected ResultData resultData;
    @XmlAttribute(name = "jtauth_can_update")
    protected String jtauth_Can_Update;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link ResultData }
     *     
     */
    public ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link ResultData }
     *     
     */
    public void setResultData(ResultData value) {
        this.resultData = value;
    }

    /**
     * Gets the value of the jtauth_Can_Update property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJtauth_Can_Update() {
        if (jtauth_Can_Update == null) {
            return "true";
        } else {
            return jtauth_Can_Update;
        }
    }

    /**
     * Sets the value of the jtauth_Can_Update property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJtauth_Can_Update(String value) {
        this.jtauth_Can_Update = value;
    }

}
